# adipylib/__init__.py

# Import functions from your .py files
from .core import hello_adipylib, add_numbers
from .keywords import extract_keywords
from .summarizer import extractive_summary

# IMPORTANT: Update the version here to match pyproject.toml
__version__ = "0.1.5"